@@ -18,4 +18,4 @@
 
 static int get_ogg_metadata(PerlIO *infile, char *file, HV *info, HV *tags);
 static int ogg_find_frame(PerlIO *infile, char *file, int offset);
-void _parse_vorbis_comments(Buffer *vorbis_buf, HV *tags, int has_framing);
+void _parse_vorbis_comments(PerlIO *infile, Buffer *vorbis_buf, HV *tags, int has_framing);
