@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/field.c 59610 2009-10-17T01:38:41.390924Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/field.c 60446 2009-11-21T02:11:55.828645Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -179,7 +179,7 @@ enum id3_field_type id3_field_type(union id3_field const *field)
  * DESCRIPTION:	parse a field value
  */
 int id3_field_parse(union id3_field *field, id3_byte_t const **ptr,
-		    id3_length_t length, enum id3_field_textencoding *encoding)
+		    id3_length_t length, enum id3_field_textencoding *encoding, struct id3_frame *frame)
 {
   assert(field);
 
@@ -329,12 +329,32 @@ int id3_field_parse(union id3_field *field, id3_byte_t const **ptr,
   case ID3_FIELD_TYPE_BINARYDATA:
     {
       id3_byte_t *data;
+      id3_byte_t skip = 0;
+      
+      // Optimization: avoid reading APIC artwork data if AUDIO_SCAN_NO_ARTWORK variable is true
+      // The length field will be correct, data will be 0
+      if ( !strcmp(frame->id, "APIC") ) {
+        char *env = getenv("AUDIO_SCAN_NO_ARTWORK");
+        if ( env != NULL && env[0] != '0' ) {
+          // env is true, skip art
+          skip = 1;
+        }
+      }
+      
+      if (skip) {
+        // Skip past binary data
+        *ptr += length;
+        field->binary.data = 0;
+      }
+      else {
+        // Parse binary data
+        data = id3_parse_binary(ptr, length);
+        if (data == 0)
+  	      goto fail;
+  	    
+  	    field->binary.data = data;
+  	  }
 
-      data = id3_parse_binary(ptr, length);
-      if (data == 0)
-	goto fail;
-
-      field->binary.data   = data;
       field->binary.length = length;
     }
     break;
