@@ -212,3 +212,106 @@ _env_true(const char *name)
   return 1;
 }
 
+// from http://jeremie.com/frolic/base64/
+int
+_decode_base64(char *s)
+{
+  char *b64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+  int bit_offset, byte_offset, idx, i, n;
+  unsigned char *d = (unsigned char *)s;
+  char *p;
+
+  n = i = 0;
+  
+  while (*s && (p=strchr(b64,*s))) {
+    idx = (int)(p - b64);
+    byte_offset = (i*6)/8;
+    bit_offset = (i*6)%8;
+    d[byte_offset] &= ~((1<<(8-bit_offset))-1);
+    
+    if (bit_offset < 3) {
+      d[byte_offset] |= (idx << (2-bit_offset));
+      n = byte_offset+1;
+    }
+    else {
+      d[byte_offset] |= (idx >> (bit_offset-2));
+      d[byte_offset+1] = 0;
+      d[byte_offset+1] |= (idx << (8-(bit_offset-2))) & 0xFF;
+      n = byte_offset+2;
+    }
+    s++;
+    i++;
+  }
+  
+  /* null terminate */
+  d[n] = 0;
+  
+  return n;
+}
+
+HV *
+_decode_flac_picture(PerlIO *infile, Buffer *buf, uint32_t *pic_length)
+{
+  uint32_t mime_length;
+  uint32_t desc_length;
+  SV *desc;
+  HV *picture = newHV();
+  
+  // Check we have enough for picture_type and mime_length
+  if ( !_check_buf(infile, buf, 8, DEFAULT_BLOCK_SIZE) ) {
+    return NULL;
+  }
+    
+  my_hv_store( picture, "picture_type", newSVuv( buffer_get_int(buf) ) );
+  
+  mime_length = buffer_get_int(buf);
+  DEBUG_TRACE("  mime_length: %d\n", mime_length);
+  if (mime_length > buffer_len(buf)) {
+    return NULL;
+  }
+  
+  // Check we have enough for mime_type and desc_length
+  if ( !_check_buf(infile, buf, mime_length + 4, DEFAULT_BLOCK_SIZE) ) {
+    return NULL;
+  }
+  
+  my_hv_store( picture, "mime_type", newSVpvn( buffer_ptr(buf), mime_length ) );
+  buffer_consume(buf, mime_length);
+  
+  desc_length = buffer_get_int(buf);
+  DEBUG_TRACE("  desc_length: %d\n", mime_length);
+  if (desc_length > buffer_len(buf)) {
+    return NULL;
+  }
+  
+  // Check we have enough for desc_length, width, height, depth, color_index, pic_length
+  if ( !_check_buf(infile, buf, desc_length + 20, DEFAULT_BLOCK_SIZE) ) {
+    return NULL;
+  }
+  
+  desc = newSVpvn( buffer_ptr(buf), desc_length );
+  sv_utf8_decode(desc); // XXX needs test with utf8 desc
+  my_hv_store( picture, "description", desc );
+  buffer_consume(buf, desc_length);
+  
+  my_hv_store( picture, "width", newSVuv( buffer_get_int(buf) ) );
+  my_hv_store( picture, "height", newSVuv( buffer_get_int(buf) ) );
+  my_hv_store( picture, "depth", newSVuv( buffer_get_int(buf) ) );
+  my_hv_store( picture, "color_index", newSVuv( buffer_get_int(buf) ) );
+  
+  *pic_length = buffer_get_int(buf);
+  DEBUG_TRACE("  pic_length: %d\n", *pic_length);
+  
+  if ( _env_true("AUDIO_SCAN_NO_ARTWORK") ) {
+    my_hv_store( picture, "image_data", newSVuv(*pic_length) );
+  }
+  else {
+    if ( !_check_buf(infile, buf, *pic_length, *pic_length) ) {
+      return NULL;
+    }
+    
+    my_hv_store( picture, "image_data", newSVpvn( buffer_ptr(buf), *pic_length ) );
+  }
+  
+  return picture;
+}
