@@ -8,5 +8,9 @@ my $file = shift;
 
 for ( 1..5000 ) {
     my $s = Audio::Scan->scan($file);
+    
+    # Test find_frame doesn't leak
+    Audio::Scan->find_frame( $file, 1000 );
+    
     sleep 0.01;
 }
